@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ebib-sidecar" "1.9.0"
+(define-package "ebib-sidecar" "20251029.1934"
   "Sidecar to show formatted reference of current Ebib Entry."
   '((emacs                      "28.1")
     (citeproc                   "0.9.4")
@@ -8,7 +8,7 @@
     (ebib                       "2.39"))
   :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
   :commit "01b12aecca0ce66f5427e7fe65012d37e7e128b2"
-  :revdesc "v1.9.0-0-g01b12aecca0c"
+  :revdesc "01b12aecca0c"
   :keywords '("bib")
   :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
   :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
